@@ -1,5 +1,6 @@
 # Framework constants
 FRAMEWORK_NAME = 'FRAMEWORK_NAME'
+ENVIRONMENT = "ENVIRONMENT"
 
 # Database Constants
 DATABASE_CONFIG = 'DATABASE_CONFIG'
@@ -7,11 +8,14 @@ DATABASE_NAME = 'DATABASE_NAME'
 DATABASE_TYPE = 'DATABASE_TYPE'
 DATABASE_DIRECTORY_PATH = 'DATABASE_DIRECTORY_PATH'
 DATABASE_URL = 'DATABASE_URL'
+DEFAULT_DATABASE_NAME = "database"
 
-RESOURCES_DIRECTORY = "RESOURCES_DIRECTORY"
+RESOURCE_DIRECTORY = "RESOURCE_DIRECTORY"
 LOG_LEVEL = 'LOG_LEVEL'
 BASE_DIR = 'BASE_DIR'
 SQLALCHEMY_DATABASE_URI = 'SQLALCHEMY_DATABASE_URI'
+SQLITE_INITIALIZED = "SQLITE_INITIALIZED"
+SQLALCHEMY_INITIALIZED = "SQLALCHEMY_INITIALIZED"
 
 
 BINANCE = "BINANCE"
@@ -43,3 +47,4 @@ MARKET = "MARKET"
 TRACK_PORTFOLIO_FROM = "TRACK_PORTFOLIO_FROM"
 SQLITE_ENABLED = "SQLITE_ENABLED"
 PORTFOLIOS = "PORTFOLIOS"
+APPLICATION_CONFIGURED = "APPLICATION_CONFIGURED"
